@@ -24,7 +24,6 @@ the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.  */
 #include "diff.h"
 #include "getopt.h"
 #include "fnmatch.h"
-#include "system.h"
 
 #ifndef DEFAULT_WIDTH
 #define DEFAULT_WIDTH 130
@@ -150,7 +149,7 @@ add_exclude_file (name)
 
   for (p = f.buffer, lim = p + f.buffered_chars;  p < lim;  p = q)
     {
-      q = memchr (p, '\n', lim - p);
+      q = (char *) memchr (p, '\n', lim - p);
       if (!q)
 	q = lim;
       *q++ = 0;
