@@ -473,7 +473,7 @@ output_1_line (text, limit, flag_format, line_flag)
   else
     {
       register FILE *out = outfile;
-      register char c;
+      register unsigned char c;
       register char const *t = text;
       register unsigned column = 0;
 
@@ -505,7 +505,7 @@ output_1_line (text, limit, flag_format, line_flag)
 	    break;
 
 	  default:
-	    if (isgraph (c) || c == ' ')
+	    if (isprint (c))
 	      column++;
 	    putc (c, out);
 	    break;
@@ -731,11 +731,11 @@ debug_script (sp)
 #if !HAVE_MEMCHR
 char *
 memchr (s, c, n)
-     char *s;
+     char const *s;
      int c;
      size_t n;
 {
-  unsigned char *p = (unsigned char *) s, *lim = p + n;
+  unsigned char const *p = (unsigned char const *) s, *lim = p + n;
   for (;  p < lim;  p++)
     if (*p == c)
       return (char *) p;
